# PyMPS
PyMPS is a python tool that implements the density matrix renormalization group (DMRG) algorithm to compute the ground state of a manybody system. The algorithm is based on the variational principle.

